@@ -1,3 +1,4 @@
+import os
 import sys
 import traceback
 import asyncio
@@ -8,10 +9,10 @@ import re
 import socket
 import time
 import threading
-import loguru
 from queue import Queue, Full, Empty
 from kafka import KafkaProducer
 from loguru import logger
+import loguru
 from sycommon.config.Config import Config, SingletonMeta
 from sycommon.middleware.context import current_trace_id
 from sycommon.tools.snowflake import Snowflake
@@ -39,7 +40,7 @@ class KafkaLogger(metaclass=SingletonMeta):
     _queue_warning_interval = 60  # 秒
     _last_queue_warning = 0
     _shutdown_timeout = 15  # 关闭超时时间，秒
-    _config = None  # 新增配置变量存储
+    _config = None  # 配置变量存储
 
     @staticmethod
     def setup_logger(config: dict):
@@ -84,38 +85,6 @@ class KafkaLogger(metaclass=SingletonMeta):
         # 设置全局异常处理器
         sys.excepthook = KafkaLogger._handle_exception
 
-        def pars_log(record):
-            match = KafkaLogger._log_pattern.match(record.strip())
-            if match:
-                time_str = match.group(1)
-                level = match.group(2)
-                module = match.group(3)
-                function = match.group(4)
-                line = int(match.group(5))
-                message_str = match.group(6)
-
-                try:
-                    message = json.loads(message_str)
-                except json.JSONDecodeError:
-                    message = message_str
-
-                return {
-                    "time": time_str,
-                    "level": level,
-                    "module": module,
-                    "function": function,
-                    "line": line,
-                    "message": message
-                }
-            else:
-                # 使用当前时间避免重复创建相同的时间字符串
-                current_time = datetime.now()
-                return {
-                    "message": record,
-                    "level": "ERROR",
-                    "time": current_time.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3]
-                }
-
         def custom_log_handler(record):
             # 检查record是否是Message对象
             if isinstance(record, loguru._handler.Message):
@@ -156,7 +125,7 @@ class KafkaLogger(metaclass=SingletonMeta):
 
                 # 检查是否有错误信息并设置detail字段
                 error_detail = ""
-                if level == "ERROR" and record.get("exception"):
+                if level == "ERROR" and record["exception"] is not None:
                     error_detail = "".join(traceback.format_exception(
                         record["exception"].type,
                         record["exception"].value,
@@ -506,12 +475,19 @@ class SYLogger:
         }
 
         # 选择日志级别
+        _log = ''
         if level == "ERROR":
-            logger.error(json.dumps(request_log, ensure_ascii=False))
+            _log = json.dumps(request_log, ensure_ascii=False)
+            logger.error(_log)
         elif level == "WARNING":
-            logger.warning(json.dumps(request_log, ensure_ascii=False))
+            _log = json.dumps(request_log, ensure_ascii=False)
+            logger.warning(_log)
         else:
-            logger.info(json.dumps(request_log, ensure_ascii=False))
+            _log = json.dumps(request_log, ensure_ascii=False)
+            logger.info(_log)
+
+        if os.getenv('DEV-LOG', 'false').lower() == 'true':
+            print(_log)
 
     @staticmethod
     def info(msg: any):
